#
# spec file for package swww
#
# Copyright (c) 2024 SUSE LLC
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swww
Version:        0.9.5
Release:        1.1
Summary:        Wallpaper daemon for Wayland
License:        GPL-3.0-only
URL:            https://github.com/LGFae/swww
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo >= 1.74.0
BuildRequires:  scdoc
BuildRequires:  zstd
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(xkbcommon)

%description
swww is a wallpaper daemon for Wayland that is controlled
at runtime. It uses LZ4 compression for frame animations
for animated wallpapers.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1

%build
./doc/gen.sh
%{cargo_build}

%install
install -Dm644 -T completions/swww.bash  %{buildroot}%{_datadir}/bash-completion/completions/swww
install -Dm644 -T completions/swww.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/swww.fish
install -Dm644 -T completions/_swww %{buildroot}%{_datadir}/zsh/site-functions/_swww
install -Dm644 -t %{buildroot}%{_mandir}/man1 doc/generated/swww*1
install -Dm755 -t %{buildroot}%{_bindir} target/release/swww{,-daemon}

%check
%{cargo_test} --locked

%files
%{_bindir}/swww
%{_bindir}/swww-daemon
%license LICENSE
%doc CHANGELOG.md README.md
%_mandir/man1/%{name}*.1%{?ext_man}

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/swww

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/swww.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_swww

%changelog
* Sun May  5 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.9.5:
  * flush the wayland_fd correctly from animations
  * specialized function for `none` transition type
  * refactor: Remove unused mutable buffer
  * fix initial black screen due to late configuration
  * don't use event_fd to wake up the main thread
  * remove sleep during cache loading
  * collapse else if into single line
  * README.md - explicit warning about gnome
  * fix switching width and height
  * use output name advertised by wl_registry as id
  * process output transforms properly
  * fix fractional scale rounding calculation
  * fix wallpaper never setting configured to 'true'
  * fix typo and update documentation
  * Add --no-cache option to swww-daemon
* Tue Apr 23 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 0.9.4:
  * less casting between types
  * implement fractional scaling
  * merge BumpPool and RawPool; remove MmapMut2 dep
  * fix output scaling
  * delete proc traversal code from client
  * do not set nonblocking mode for socket
  * create ImageRequest and AnimationRequest structs
  * update documentation regarding sockets and `init`
  * Try pinging the daemon instead of inspecting /proc.
  * Fix over-eager errors.
  * Fix silly PathBuf recreation.
  * Adjust instance checking to work with separate sockets.
  * Bind to a separate socket per-display.
  * typo when setting output's description
  * fix transitions performance
  * add SIGHUP to list of signals we catch
  * reimplement the cache and error on unknown events
  * fix initialization
  * delete sctk dependency
  * Implement layer shell manually
  * implement WlOutput manually
  * implement WlRegistry
  * implement wl_shm
  * delete CompositorState import
  * implement delegate_compositor manually
  * do not parallelize the simple transition
  * fix sigaction on systems with different libc
  * add bitcode git url to exceptions in cargo-deny
  * use bitcode instead of rykv
  * Fix build on i686 (32bit x86)
  * automatically delete old socket in daemon
  * Update README.md
  * use eventfd instead of pipes to awake the daemon
  * fix resize when image is larger than monitor
  * simplify daemon's transitions
  * refactor client's image format choice
  * Increase thread pool stack size of daemon to 512KiB
* Sun Mar 31 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.9.1:
  * deprecate swww init
  * update CHANGELOG.md
  * add BSD2 and Apache2.0 with LLVM-exception license
  * update MSRV to 1.74.0
  * support animations when piping from stdin
  * update dependencies
  * forward init format option to daemon
  * option to force use of a wayland_shm format
  * prevent UB from a malformed BitPack at decompression
  * do not use unsafe for the FORMAT statics
  * specialize transitions for 3channels
  * Use 3 channel formats when available
  * only swap R and B channels when necessary
  * document unsafe invariants
  * compression functions api signal errors better
  * reuse the buffer when compressing
  * use system lz4 library
  * implement sse variants of compress and decompress
  * new compression functions
  * Implement frame callbacks and a new memory pool
  * refactor version.sh
  * fix out-of-bounds access in decompression
  * process clear-cache before sending requests
  * rename `Init` request/answer to `Ping`
  * wait for daemon initialization before any requests
  * wait for daemon initialization before certain requests
  * add restore command
  * wait for child swww process, to prevent zombies
  * fix randomize script trying to use directories as images
  * fix gif animations overlapping when sending two gifs
  * center cropped images larger than the monitor
  * make an fps an u16
  * Format code with cargo fmt
  * Update ahash to 0.7.8
  * remove all cache contents on clean-cache
  * support animated pngs
  * typo in comment
  * fix busyloop while waiting for WlBuffers to be released
  * fix single image webp and gif
  * fix let_underscore_lock lint
  * explicit versions for all dependencies
* Tue Jan 30 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.2:
  * update daemon dependencies
  * implement clear-cache command
  * bump dependencies and fix versioning
  * Update README.md - add final photo source
  * Animated WebP Support + Memory Optimisations
  * image_pad: fix capacity of Vec
- Remove cargo_config. part of vendored tarball now.
* Sun Aug 13 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Replace obsoleted `disabled` option with `manual`
* Tue Jul 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.1:
  * fix sending images in quick succession
  * remember to set exclusive zone to -1
  * remove condvar from wallpaper
  * overhaul transition waiting mechanism
  * nuke gif processing pipeline
  * load cache on `swww init`
  * add a `none` transition
  * fix clear exiting daemon
  * Version 0.8.0
  * update CHANGELOG and man-pages
  * fix rebase error
  * spell check example scripts
  * fix fade transition
  * fix failing test
  * update changelog and todo
  * stop using signals hack to wake main thread
  * cache only tries loading gifs from correct version
  * fix deadlock when resizing monitor
  * put Arc<SlotPool> in wallpaper struct
  * name threads for better errors
  * Rework syncing animations between monitors
  * bump dependencies - new rust version
  * reimplement cache with a different strategy
  * fix scaling images
  * fix deadlock on `clear` with on-going animation
  * update documentation
  * reimplement syncing animations
  * fix wrong transmute
  * rename utils::communication -> utils::ipc
  * use Box instead of Vec in all communication types
  * better values for step when falling back to simple
  * fix animation preventing transition to begin
  * change serde for rkyv for serialization
  * compress animation frames in a pipeline
  * only lock what is necessary
  * Rename daemon's modules and structs for clarity
  * Sending RGB instead of RGBA images
  * nuke cache
  * syncronizing with condvars
  * fix canvas pool not being ready
  * fix crash when changing scale factor
  * rename modules and fix cache import
  * animations working
  * transitions working
  * begin implementation - working for static images
  * add to docs
  * add doc for --invert-y
  * fix invert_y for percentage values
  * impl invert_y flag
  * fix spelling
  * feat: add option to resize image to fit screen instead of cropping
  * fix: don't skew images padded from odd widths
  * fix
  * add doc
  * readd `simple` and rename to `fade`
  * cargo fmt && cargo clippy
  * re add fallback
  * impl beziers for simple
* Thu Jun  8 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update vendored dependencies. Resolves CVE and bsc#1212009.
* Sun May  7 2023 uncomfy+openbuildservice@uncomfyhalomacro.pl
- Update to version 0.7.3:
  * Log error instead of returning
  * Send status update to systemd when daemon has initialized
  * split outputs with ,
  * bump dependencies
  * start animation right after finishing transition
  * better spread of different bytes
  * create benchmarks for compression functions
  * update dependencies
  * stop-gag zip_eq panic on slices of unequal size
  * check if cache dir is actually a dir
  * use std::thread::scope for gif frames
  * wait until all gif's frames are ready
  * `--transition-step` with `simple` saner default
  * fix: Missing `/` when using `$HOME/.cache/swww`
* Sun May  7 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Build and package man pages
- Add cargo version requirement
* Sat Mar 18 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Fix specfile.
- Fix installation of swww-daemon.
* Fri Mar 10 2023 uncomfy+openbuildservice@uncomfyhalomacro.pl
- Update to version 0.7.2:
  * update dependencies
  * man-pages
  * Sync animations
  * update changelog
  * ignore integration_tests by default
  * cache the images to reload them on startup
  * prepare 0.7.1 release
  * update dependencies
  * cargo clippy and style
  * update CHANGELOG.md
  * fix integration_tests calling incorrect daemon bin
  * add ability to use screen cords instead of percentages in `--transition-pos`
  * typo: pipw -> pipe
  * fix reading image from stdin (don't cannonicalize)
  * document `--no_resize` and `--fill_color` args
  * fix `swww` query not returning correct image
  * change the version in Cargo.toml
* Mon Jan 30 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.7.0
  * update changelog
  * nuke `fix_zsh_completion.sh`
  * bump dependencies
  * inline printed variables where possible
  * use `with_guessed_format` to detect image type
  * [utils/comp_decomp] handle scale factor reduction
  * new transition: wave (#66)
  * [client] use scaling when sending images
* Mon Jan 23 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.6.0+git18:
  * fix panic on gif with identical frames
  * implement --no-resize for animated gifs
  * implement --no-resize option
  * fix insane problem introduced by 29e2683
  * change default transition step value
  * implement reading image from stdin
* Mon Oct 10 2022 Jan Engelhardt <jengelh@inai.de>
- Trim excess marketing from description
* Sun Oct  9 2022 uncomfy+openbuildservice@uncomfyhalomacro.pl
- Update to version 0.4.3+git14:
  * bump dependencies (clap went from 3.x to 4.x)
  * Render the cursor on an empty desktop
  * Fixed a typo
  * This protocol is not actually required / used
  * Use safer type conversion
  * docs: Put type in backticks
  * Formatting
  * Simplify closure that just calls a function
  * Avoid copying data unnecessarily
  * Remove unnecessary Option
- Install shell completions for zsh, bash, and fish
* Sun Oct  9 2022 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Initial spec for swww version 0.4.3
